@@ -5,7 +5,7 @@
 import shutil
 import os
 from pathlib import Path
-import objectUtils as objUtils
+import objectUtils as obj
 import file_write as write
 import string_utils as strUtils
 import file as f
@@ -35,9 +35,9 @@ def exists(file_path):
 
 def get_folders(**kwargs):
     dir_array = []
-    search_path = objUtils.get_kwarg(['search path', 'search'], os.getcwd(), str, **kwargs)
-    recursive = objUtils.get_kwarg(['recursive', 'recurse'], True, bool, **kwargs)
-    ignore_array = objUtils.get_kwarg(['ignore', 'ignore_array'], [], list, **kwargs)
+    search_path = obj.get_kwarg(['search path', 'search'], os.getcwd(), str, **kwargs)
+    recursive = obj.get_kwarg(['recursive', 'recurse'], True, bool, **kwargs)
+    ignore_array = obj.get_kwarg(['ignore', 'ignore_array'], [], list, **kwargs)
     # print(f"search_path: {search_path}")
 
     # # pylint: disable=unused-variable
@@ -85,13 +85,13 @@ def get_files(**kwargs):
             A list of dictionaries containing all matching files.
     '''
     file_array = []
-    search_path = objUtils.get_kwarg(['search path', 'search'], os.getcwd(), (str, list), **kwargs)
+    search_path = obj.get_kwarg(['search path', 'search'], os.getcwd(), (str, list), **kwargs)
     if isinstance(search_path, list) is False:
         search_path = [search_path]
-    recursive = objUtils.get_kwarg(['recursive', 'recurse'], True, bool, **kwargs)
-    ignore_array = objUtils.get_kwarg(['ignore', 'ignore_array', 'exclude'], [], (str, list), **kwargs)
+    recursive = obj.get_kwarg(['recursive', 'recurse'], True, bool, **kwargs)
+    ignore_array = obj.get_kwarg(['ignore', 'ignore_array', 'exclude'], [], (str, list), **kwargs)
     extension_array = strUtils.format_extension(
-        objUtils.get_kwarg(['extensions', 'ext', 'extension'], [], (str, list), **kwargs)
+        obj.get_kwarg(['extensions', 'ext', 'extension'], [], (str, list), **kwargs)
     )
 
     if isinstance(ignore_array, list) is False:
@@ -194,8 +194,8 @@ def mirror(src, des, **kwargs):
     empty_file_size = 0
 
     # if EMPTY_FILES is True, it creates a duplicate file with no content.
-    empty_files = objUtils.get_kwarg(['empty files'], True, bool, **kwargs)
-    empty_file_size = objUtils.get_kwarg(['empty file size', 'file sizes'], True, bool, **kwargs)
+    empty_files = obj.get_kwarg(['empty files'], True, bool, **kwargs)
+    empty_file_size = obj.get_kwarg(['empty file size', 'file sizes'], True, bool, **kwargs)
 
     src = os.path.abspath(src)
     src_prefix = len(src) + len(os.path.sep)
