@@ -31,6 +31,8 @@ SRC_PATH_SYNONYMS = ["source", "src", "src path", "source path", "file path"]
 
 # todo - DOCUMENTATION FOR METHODS
 
+# // TODO:Get optional file access,create,modified formatting.
+
 
 def get_data(file_path, **kwargs):
     '''
@@ -209,12 +211,12 @@ def delete(file_path, **kwargs):
             _thread_file_action(file_list, action="delete", max_threads=max_threads, min_thread_threshold=min_thread_threshold, shred=shred)
             return
 
-        for file in file_path:
+        for file in file_list:
             if isinstance(file, (dict)):
                 if 'file_path' in file:
                     _delete_single_file(file['file_path'], shred)
-            if isinstance(file_path, (str)):
-                _delete_single_file(file_path, shred)
+            if isinstance(file, (str)):
+                _delete_single_file(file, shred)
     return True
 
 
